@@ -1119,9 +1119,9 @@ class DADSignal(DADSignalInfo):
             # yield header row
             yield (
                 f'Retention Time ({self.DEFAULT_TIME_UNIT})',
-                f'{self.wavelength} intensity ({self.spectrum.data.yunits})',
-                f'{self.reference.wavelength} reference intensity ({self.spectrum.data.yunits})',
-                f'{self.wavelength} referenced intensity ({self.spectrum.data.yunits})',
+                f'{self.wavelength} intensity ({self.spectrum.chromatogram.yunits})',
+                f'{self.reference.wavelength} reference intensity ({self.spectrum.chromatogram.yunits})',
+                f'{self.wavelength} referenced intensity ({self.spectrum.chromatogram.yunits})',
             )
             for rt, intensity, ref_intensity, referenced in zip(
                 self.retention_times,
@@ -1134,7 +1134,7 @@ class DADSignal(DADSignalInfo):
             # yield header row
             yield (
                 f'Retention Time ({self.DEFAULT_TIME_UNIT})',
-                f'{self.wavelength} intensity ({self.spectrum.data.yunits})',
+                f'{self.wavelength} intensity ({self.spectrum.chromatogram.yunits})',
             )
             for rt, intensity in zip(
                     self.retention_times,
@@ -1213,7 +1213,9 @@ class HPLCSample(HPLCSampleInfo):
         """
         if isinstance(file_path, pathlib.Path) is False:
             file_path = pathlib.Path(file_path)
-        if file_path.suffix != '.D' is False or os.path.isdir(file_path) is False:
+        if file_path.suffix != '.D' and file_path.name.endswith('.D') is False:
+            raise ValueError(f'the file "{file_path}" does not appear to be a .D sample')
+        if file_path.is_dir() is False:
             raise ValueError(f'The file path "{file_path}" does not appear to be a valid Agilent sample directory')
         sample_info_values = HPLCSampleInfo.find_and_get_metadata(file_path)
         try:
