@@ -6,17 +6,54 @@ import configparser
 import pathlib
 import logging
 import threading
-from typing import Union, List, Tuple
+from typing import Union, List, Tuple, Optional
 
 logger = logging.getLogger(__name__)
 
 
 # acquiring regex
 _acq_re = re.compile(
-    'CURRDATAFILE:(?P<file_number>\d+)\|(?P<file_name>[^\n]+)'
+    'CURRDATAFILE:((?P<file_number>\d+)\|)?(?P<file_name>[^\n]+)'
 )
 
 
+def newsort_subdirs(*directories: pathlib.Path) -> List[pathlib.Path]:
+    """returns the provided directories sorted in order of modified date"""
+    return sorted(
+        directories,
+        key=lambda x: x.stat().st_mtime,
+        reverse=True,
+    )
+
+
+def get_subdirectories(parent_directory: pathlib.Path) -> List[pathlib.Path]:
+    """Gets a list of the subdirectories in the provided directory"""
+    return [
+        directory
+        for directory in parent_directory.iterdir()
+        if directory.is_dir()
+    ]
+
+
+def get_newest_nonD_subdirectory(directory: pathlib.Path) -> pathlib.Path:
+    """
+    Gets the newest non .D subdirectory contained in the provided directory. The method will keep digging in
+    subdirectories until it identifies a .D folder or bottoms out.
+
+    :param directory: directory to search
+    """
+    while True:
+        try:
+            next_subdir = newsort_subdirs(
+                *get_subdirectories(directory)
+            )[0]
+        except IndexError:  # if we've reached the bottom, this is the lowest we can dig
+            return directory
+        if next_subdir.name.endswith('.D'):
+            return directory
+        directory = next_subdir
+
+
 class AcquisitionSearch:
     # lock if acquisition file is found
     _located = threading.Event()
@@ -31,11 +68,24 @@ class AcquisitionSearch:
     # flag to indicate whether the "start all monitors" flag has been set
     _all_started: bool = False
 
+    # default flag for searching the newest modified subdirectory
+    SEARCH_NEWEST_MODIFIED: bool = True
+    # default flag for searching the parent directory
+    SEARCH_PARENT_DIRECTORY: bool = True
+    # default flag for searching the top-level directory
+    SEARCH_TOP_DIRECTORY: bool = False
+    # default flag for searching all subdirectory (deep search, longest)
+    SEARCH_ALL_DIRECTORIES: bool = False
+
     def __init__(self,
                  data_path: Union[str, pathlib.Path],
                  cycle_time: float = 1.,
                  always_search: bool = False,
                  autostart: bool = True,
+                 search_newest: Optional[bool] = None,
+                 search_parent: Optional[bool] = None,
+                 search_top: Optional[bool] = None,
+                 search_all: Optional[bool] = None,
                  ):
         """
         An Agilent ChemStation data path monitoring class. This class will monitor for sequence flags and will live-update
@@ -46,6 +96,17 @@ class AcquisitionSearch:
         :param always_search: flag to enable continuous searching, even when a file has been located in another instance
         :param autostart: flag to control autostart (if the all started flag is set, setting this to True will prevent
             the monitor thread from starting and require the user to start the thread manually)
+        :param search_newest: whether the search algorithm should search the newest modified subdirectory tree (this is
+            the most common location for the flag file and should account for most scenarios. If not specified,
+            the class default SEARCH_NEWEST_MODIFIED will be used.
+        :param search_parent: whether the search algorithm should search the parent directory (this is normally only
+            required if the path was manually specified. If not specified,
+            the class default SEARCH_PARENT_DIRECTORY will be used.
+        :param search_top: whether the search algorithm should search the top-level directory (searches the top level
+            for all subdirectories of the parent; slow). If not specified,
+            the class default SEARCH_TOP_DIRECTORY will be used.
+        :param search_all: whether the search algorithm should search all subdirectories (very, very slow). If not specified,
+            the class default SEARCH_ALL_DIRECTORIES will be used.
         """
         if isinstance(data_path, pathlib.Path) is False:
             data_path = pathlib.Path(data_path)
@@ -58,6 +119,12 @@ class AcquisitionSearch:
         self._acquiring_path: pathlib.Path = None
         self._current_number: int = None
         self._current_file: str = None
+        self.search_newest = search_newest or self.SEARCH_NEWEST_MODIFIED
+        self.search_parent = search_parent or self.SEARCH_PARENT_DIRECTORY
+        self.search_top = search_top or self.SEARCH_TOP_DIRECTORY
+        self.search_all = search_all or self.SEARCH_ALL_DIRECTORIES
+        if not any([self.search_newest, self.search_parent, self.search_top, self.search_all]):
+            raise ValueError('no search modes were specified for the acquisition search')
         self.cycle_time = cycle_time
         self._monitor_thread = threading.Thread(
             target=self._acquiring_monitor,
@@ -67,7 +134,7 @@ class AcquisitionSearch:
         self._killswitch = threading.Event()
         self.instances.append(self)
         self.always_search = always_search
-        if self._all_started and autostart:
+        if autostart:
             self._monitor_thread.start()
         # start the monitor thread
         AcquisitionSearch._start_class_acquiring_monitor()
@@ -124,11 +191,7 @@ class AcquisitionSearch:
     @property
     def newsorted_subdirectories(self) -> List[pathlib.Path]:
         """subdirectories of the root path sorted by date modified in newest to oldest order"""
-        return sorted(
-            self.subdirectories,
-            key=lambda x: x.stat().st_mtime,
-            reverse=True,
-        )
+        return newsort_subdirs(*self.subdirectories)
 
     def find_acquiring(self) -> Union[pathlib.Path, None]:
         """
@@ -137,22 +200,40 @@ class AcquisitionSearch:
 
         :return: path to acquiring.txt (if found)
         """
-        # check parent directory (usually only the case if the path was manually specified)
-        in_current_dir = list(self.data_parent.glob('ACQUIRING.TXT'))
-        if len(in_current_dir) > 0:
-            return in_current_dir[0]
-        # search top level of subdirectories (most common file location)
-        for subdir in self.newsorted_subdirectories:
-            try:
-                return next(subdir.glob('ACQUIRING.TXT'))
-            except StopIteration:
-                continue
-        # recursively search subdirectories (slow)
-        for subdir in self.newsorted_subdirectories:
-            try:
-                return next(subdir.glob('**/ACQUIRING.TXT'))
-            except StopIteration:
-                continue
+        if self.search_newest:
+            # dig through the most recently modified
+            logger.debug(f'{self} checking newest modified subdir')
+            newest_subdir = get_newest_nonD_subdirectory(self.data_parent)
+            if newest_subdir:
+                in_subdir = list(newest_subdir.glob('ACQUIRING.TXT'))
+                if len(in_subdir) > 0:
+                    return in_subdir[0]
+        if self.search_parent:
+            logger.debug(f'{self} checking top level')
+            # check parent directory (usually only the case if the path was manually specified)
+            in_current_dir = list(self.data_parent.glob('ACQUIRING.TXT'))
+            if len(in_current_dir) > 0:
+                return in_current_dir[0]
+        if self.search_top:
+            logger.debug(f'{self} checking top level of subdirectories')
+            # search top level of subdirectories (most common file location)
+            for subdir in self.newsorted_subdirectories:
+                try:
+                    if self._killswitch.is_set():
+                        return
+                    return next(subdir.glob('ACQUIRING.TXT'))
+                except StopIteration:
+                    continue
+        if self.search_all:
+            logger.debug(f'{self} deep search')
+            # recursively search subdirectories (slow)
+            for subdir in self.newsorted_subdirectories:
+                try:
+                    if self._killswitch.is_set():
+                        return
+                    return next(subdir.glob('**/ACQUIRING.TXT'))
+                except StopIteration:
+                    continue
 
     @staticmethod
     def current_num_and_file(path: Union[str, pathlib.Path]) -> Tuple[int, str]:
@@ -291,7 +372,7 @@ class AcquisitionSearch:
     def start_monitoring_all_paths(cls):
         """starts the monitor thread on all data paths"""
         if cls._all_started is False:
-            logger.debug('starting all monitor threads')
+            logger.info('starting all monitor threads')
             cls._all_started = True
             for inst in cls.instances:
                 inst.start_monitor()
